@@ -19,7 +19,7 @@
 //' @param dis A distance matrix NxN that specifies how far all the pairs
 //' of units in the population are.
 //' @param nsamp Sample size.
-//' @param bexp Parameter \eqn{\beta} for the algorithm. The higher
+//' @param beta Parameter \eqn{\beta} for the algorithm. The higher
 //' \eqn{\beta} is, the more the sample is going to be spread (default = 10).
 //' @param nrepl Number of samples to draw (default = 1).
 //' @return Returns a matrix \code{nrepl} x \code{nsamp}, which contains the
@@ -49,16 +49,16 @@
 //'
 //' # Example 3
 //' # Draw 2 samples of dimension 15 with constant inclusion probabilities
-//' # equal to nsamp/N, with N = population size, and an increased level of spread, bexp = 20
+//' # equal to nsamp/N, with N = population size, and an increased level of spread, beta = 20
 //' dis <- as.matrix(dist(cbind(lucas_abruzzo$x, lucas_abruzzo$y))) # distance matrix
 //' con <- rep(0, nrow(dis)) # vector of constraints
 //' stand_dist <- stprod(mat = dis, vec = con) # standardized matrix
-//' s <- hpwd(dis = stand_dist, nsamp = 15, bexp = 20, nrepl = 2) # drawn samples
+//' s <- hpwd(dis = stand_dist, nsamp = 15, beta = 20, nrepl = 2) # drawn samples
 //' }
 //' @export
 // [[Rcpp::export]]
 
-arma::mat hpwd(arma::mat dis, int nsamp, double bexp = 10, int nrepl=1)
+arma::mat hpwd(arma::mat dis, int nsamp, double beta = 10, int nrepl=1)
 {
   int npop = dis.n_rows;
   if(dis.is_square() == FALSE)
@@ -69,9 +69,9 @@ arma::mat hpwd(arma::mat dis, int nsamp, double bexp = 10, int nrepl=1)
   {
     Rcpp::warning("The distance matrix is not symmetric.");
   }
-  if(nsamp > npop)
+  if(nsamp >= npop)
   {
-    throw Rcpp::exception("Sample size greater than population size.");
+    throw Rcpp::exception("Sample size equal or greater than population size.");
   }
   if(nsamp <= 0)
   {
@@ -86,7 +86,7 @@ arma::mat hpwd(arma::mat dis, int nsamp, double bexp = 10, int nrepl=1)
   arma::vec c(npop);
   arma::vec psel(npop);
   double drawn;
-  dis = arma::pow(dis, bexp);
+  dis = arma::pow(dis, beta);
   dis.diag().fill(0);
   for(int cc = 1; cc <= nrepl; cc++)
   {
